# Data Processing and Preservation System (DPPS)

The Data Processing and Preservation Systems is one of the major components of CTAO Computing.

It is responsible for transferring and preserving the DL0 data produced by
[ACADA](https://gitlab.cta-observatory.org/cta-computing/acada/array-control-and-data-acquisition)
and then processing it to data level DL3.

See [the documentation](http://cta-computing.gitlab-pages.cta-observatory.org/dpps/dpps) for more details.
